@@ -569,8 +569,7 @@ def brain(src, cmap=None, vmin=None, vmax=None, surf='inflated',
             brain.add_ndvar(ndvar, cmap, vmin, vmax, smoothing_steps, colorbar, time_label)
 
     if mask is not False:
-        color = (0, 0, 0, 0.5) if mask is True else mask
-        brain.add_mask(source, color, smoothing_steps, None, subjects_dir)
+        brain.add_mask(source, mask, smoothing_steps, None, subjects_dir)
 
     if parallel:
         brain.set_parallel_view(scale=True)
@@ -1188,7 +1187,7 @@ class SequencePlotter:
             'parallel': parallel, 'cortex': cortex, 'mask': mask}
 
     def set_parallel_view(self, forward=None, up=None, scale=None):
-        "Set view for all plots (see :meth:`~._brain_obj.Brain.set_parallel_view`"
+        "Set view for all plots (see :meth:`~.brain_object.Brain.set_parallel_view`"
         if forward is not None:
             self._parallel_view['forward'] = forward
         if up is not None:
